@@ -20,7 +20,7 @@ imageSetMaker::imageSetMaker(QWidget* parent) :
 
         // UI elements
         vertLayout.append(new QVBoxLayout);
-        imgPrev.append(new QLabel);
+        imgBtnPrev.append(new QPushButton);
     }
 
     setupIsmMenuBar();
@@ -32,10 +32,10 @@ imageSetMaker::imageSetMaker(QWidget* parent) :
     for(i=0; i<4; i++)
         vertLayout[i]->setAlignment(Qt::AlignTop);
 
-    imgPrev[0] = ui->imgPrev1;
-    imgPrev[1] = ui->imgPrev2;
-    imgPrev[2] = ui->imgPrev3;
-    imgPrev[3] = ui->imgPrev4;
+    imgBtnPrev[0] = ui->imgBtnPrev1;
+    imgBtnPrev[1] = ui->imgBtnPrev2;
+    imgBtnPrev[2] = ui->imgBtnPrev3;
+    imgBtnPrev[3] = ui->imgBtnPrev4;
 
     ui->visibChkbox->setChecked(false);
 
@@ -59,8 +59,21 @@ imageSetMaker::imageSetMaker(QWidget* parent) :
     // $                Until the end of the string
     ui->nameEdit->setValidator(new QRegExpValidator(nameRegExp, ui->nameEdit));
 
-    // Create 4 QMaemo5ValueButtons on main screen
-    createImgBtns();
+    for(i=0; i<4; i++) {
+        imgBtnPrev[i]->setText(tr("Image ") + QString::number(i+1));
+        imgBtnPrev[i]->setStyleSheet("color: black; border-image: url(:/images/select"
+                                     + QString::number(i+1)
+                                     + ".png);");
+    }
+
+    connect(imgBtnPrev[0], SIGNAL(clicked()),
+            this, SLOT(clickedImgBtnPrev0()));
+    connect(imgBtnPrev[1], SIGNAL(clicked()),
+            this, SLOT(clickedImgBtnPrev1()));
+    connect(imgBtnPrev[2], SIGNAL(clicked()),
+            this, SLOT(clickedImgBtnPrev2()));
+    connect(imgBtnPrev[3], SIGNAL(clicked()),
+            this, SLOT(clickedImgBtnPrev3()));
 
     connect(copyToBtn[0], SIGNAL(clicked()),
             this, SLOT(clickedCopyToBtn0()));
@@ -90,29 +103,6 @@ imageSetMaker::~imageSetMaker() {
 
 
 //********* START imageSetMaker public functions *******************
-void imageSetMaker::createImgBtns() {
-    // Setup 4 imgBtn's on main screen
-    for(i=0; i<4; i++) {
-        imgBtn.append(new QMaemo5ValueButton);
-        imgBtn[i]->setParent(this);
-        imgBtn[i]->setMinimumSize(190, 60);
-        imgBtn[i]->setMaximumSize(190, 60);
-        imgBtn[i]->setText(tr("Image ") + QString::number(i+1));
-        imgBtn[i]->setValueText(tr("(no image)"));
-        imgBtn[i]->setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered);
-        vertLayout[i]->addWidget(imgBtn[i], 0, Qt::AlignHCenter);
-    }
-
-    connect(imgBtn[0], SIGNAL(clicked()),
-            this, SLOT(clickedImgBtn0()));
-    connect(imgBtn[1], SIGNAL(clicked()),
-            this, SLOT(clickedImgBtn1()));
-    connect(imgBtn[2], SIGNAL(clicked()),
-            this, SLOT(clickedImgBtn2()));
-    connect(imgBtn[3], SIGNAL(clicked()),
-            this, SLOT(clickedImgBtn3()));
-}
-
 void imageSetMaker::setupIsmMenuBar() {
     ismMenuActionReset = new QAction(tr("Reset screen"), this);
     ismMenuActionAbout = new QAction(tr("About..."), this);
@@ -163,18 +153,19 @@ bool imageSetMaker::resCheck(QString curFile) {
     }
 }
 
-void imageSetMaker::setupCopyToBtn(int imgBtnNum) {
+void imageSetMaker::setupCopyToBtn(int imgBtnPrevNum) {
     // Setup the current copyToBtn
     // If hidden after resetScreen(), show it again
-    if(*copyToBtnExists[imgBtnNum] == true && copyToBtn[imgBtnNum]->isVisible() == false)
-        copyToBtn[imgBtnNum]->setVisible(true);
-    else if(*copyToBtnExists[imgBtnNum] == false) {
-        copyToBtn[imgBtnNum]->setParent(this);
-        copyToBtn[imgBtnNum]->setMaximumSize(190, 50);
-        copyToBtn[imgBtnNum]->setText(tr("Copy to..."));
-        vertLayout[imgBtnNum]->addWidget(copyToBtn[imgBtnNum], 0, Qt::AlignHCenter);
+    if(*copyToBtnExists[imgBtnPrevNum] == true && copyToBtn[imgBtnPrevNum]->isVisible() == false)
+        copyToBtn[imgBtnPrevNum]->setVisible(true);
+    else if(*copyToBtnExists[imgBtnPrevNum] == false) {
+        copyToBtn[imgBtnPrevNum]->setParent(this);
+        copyToBtn[imgBtnPrevNum]->setMaximumSize(190, 50);
+        copyToBtn[imgBtnPrevNum]->setText(tr("Copy to..."));
+        copyToBtn[imgBtnPrevNum]->setVisible(true);
+        vertLayout[imgBtnPrevNum]->addWidget(copyToBtn[imgBtnPrevNum], 0, Qt::AlignHCenter);
     }
-    *copyToBtnExists[imgBtnNum] = true;
+    *copyToBtnExists[imgBtnPrevNum] = true;
 }
 
 void imageSetMaker::createCopyToDialog(int copyToBtnNum) {
@@ -253,13 +244,9 @@ void imageSetMaker::createCopyToDialogBtns() {
 }
 
 void imageSetMaker::updateImg(int pathNum) {
-    // Update imgBtn and imgPrev according to *imgPath[pathNum]
-    for(i=0; i<4; i++) {
-        if(pathNum == i) {
-            imgPrev[i]->setPixmap(*imgPath[i]);
-            imgBtn[i]->setValueText(QFileInfo(*imgPath[i]).fileName());
-        }
-    }
+    // Update imgBtnPrev[#] according to *imgPath[pathNum]
+    imgBtnPrev[pathNum]->setStyleSheet("border-image: url(" + *imgPath[pathNum] + ")");
+    imgBtnPrev[pathNum]->setText("");
 }
 
 void imageSetMaker::saveDesktopFile() {
@@ -349,10 +336,10 @@ void imageSetMaker::checkDesktopFileSaved() {
 
 
 //********* START imageSetMaker public slots *******************
-void imageSetMaker::clickedImgBtn0() { openImage(0); }
-void imageSetMaker::clickedImgBtn1() { openImage(1); }
-void imageSetMaker::clickedImgBtn2() { openImage(2); }
-void imageSetMaker::clickedImgBtn3() { openImage(3); }
+void imageSetMaker::clickedImgBtnPrev0() { openImage(0); }
+void imageSetMaker::clickedImgBtnPrev1() { openImage(1); }
+void imageSetMaker::clickedImgBtnPrev2() { openImage(2); }
+void imageSetMaker::clickedImgBtnPrev3() { openImage(3); }
 
 void imageSetMaker::updateSaveBtn() {
     if(ui->nameEdit->text().isEmpty()
@@ -399,7 +386,7 @@ void imageSetMaker::createAboutDialog() {
     // Only create a new dialog if it hasn't been made yet
     if(aboutDialogExists == false) {
         aboutDialog = new QDialog(this);
-        aboutDialog->setWindowTitle("Image Set Maker 0.2.1-1" + tr(" for ") + "Nokia N900");
+        aboutDialog->setWindowTitle("Image Set Maker 0.3-1" + tr(" for ") + "Nokia N900");
 
         aboutIcon = new QLabel;
         aboutIcon->setPixmap(QPixmap(":/images/imagesetmaker.png"));
@@ -463,7 +450,7 @@ void imageSetMaker::copyToOthers() {
     }
 
     // Copy from source path to imgPath[#], based on checked buttons
-    // then updates imgBtn[#], imgPrev[#] and copyToBtn[#]
+    // then updates imgBtnPrev[#] and copyToBtn[#]
     for(j=0; j<4; j++) {
         if(copyToDialogBtn[j]->isChecked() == true) {
             *imgPath[j] = *srcPath;
@@ -479,11 +466,13 @@ void imageSetMaker::resetScreen() {
     // nameEdit
     ui->nameEdit->setText("");
     ui->visibChkbox->setChecked(false);
-    // imgPath, imgPrev, imgBtn, copyToBtn
+    // imgPath, imgBtnPrev, copyToBtn
     for(i=0; i<4; i++) {
         *imgPath[i] = "";
-        imgPrev[i]->setText("(no image)");
-        imgBtn[i]->setValueText("(no image)");
+        imgBtnPrev[i]->setText(tr("Image ") + QString::number(i+1));
+        imgBtnPrev[i]->setStyleSheet("color: black; border-image: url(:/images/select"
+                                     + QString::number(i+1)
+                                     + ".png);");
         copyToBtn[i]->setVisible(false);
     }
     // saveBtn
